@@ -13,7 +13,7 @@ use AWS::XRay::Buffer;
 use Exporter 'import';
 our @EXPORT_OK = qw/ new_trace_id capture capture_from trace /;
 
-our $VERSION = "0.06";
+our $VERSION = "0.07";
 
 our $TRACE_ID;
 our $SEGMENT_ID;
@@ -169,6 +169,24 @@ sub parse_trace_header {
     return ($trace_id, $segment_id, $sampled);
 }
 
+sub add_capture {
+    my ($class, $package, @methods) = @_;
+    no warnings 'redefine';
+    no strict 'refs';
+    for my $method (@methods) {
+        my $orig = $package->can($method) or next;
+        *{"${package}::${method}"} = sub {
+            my @args = @_;
+            capture(
+                "${package}::${method}",
+                sub {
+                    $orig->(@args);
+                },
+            );
+        };
+    }
+}
+
 1;
 __END__
 
@@ -250,6 +268,14 @@ capture_from() parses the trace header and capture the $code with sub segment of
 
 Parse a trace header (e.g. "Root=1-5759e988-bd862e3fe1be46a994272793;Parent=53995c3f42cd8ad8").
 
+=head2 add_capture($package, $method1[, $method2, ...])
+
+add_capture() adds a capture to package::method.
+
+    AWS::XRay->add_capture("MyApp", "foo", "bar");
+
+The segments of these captures are named as "MyApp::foo" and "MyApp::bar".
+
 =head1 CONFIGURATION
 
 =head2 sampling_rate($rate)
